<?php
namespace Controller;


use Util\Utilities;
use Util\Messages;
use Zeedhi\Framework\Controller\Simple;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;

class CalendarWeeklyDays extends Simple
{

    /**
     * @var \Service\CalendarWeeklyDays
     */
    private $calendarWeeklyDaysService;
    /**
     * @var \Service\CalendarDetail
     */
    private $calendarDetailService;

    const PADRAO_WORK_WEEK = "Padrão";

    public function __construct(\Service\CalendarWeeklyDays $calendarWeeklyDaysService,\Service\CalendarDetail $calendarDetailService)
    {
        $this->calendarWeeklyDaysService = $calendarWeeklyDaysService;
        $this->calendarDetailService = $calendarDetailService;
    }

    public function find(Request\Filter $request, Response $response)
    {
        try {
            $filters = $request->getFilterCriteria()->getConditions();
            $calendar = Utilities::getValueInFilterDataSourceByName($filters,'CALENDAR', true);
            $id = Utilities::getValueInFilterDataSourceByName($filters,'ID', true);
            $filterString = Utilities::createQueryFiltered($filters);
            $dataSet = $this->calendarWeeklyDaysService->findCalendarWeeklyDays($calendar,$id,true,$filterString);
            $response->addDataset(new DataSet('calendarWeeklyDays', $dataSet));

        }catch(\Exception $e){
            $response->addMessage(new Response\Message('Erro inesperado :'.$e->getMessage(),Response::STATUS_ERROR));
        }
    }
    public function calendarWeeklyDaysStructure(Request\Filter $request, Response $response)
    {
        try {
            $filters = $request->getFilterCriteria()->getConditions();
            $structureId = Utilities::getValueInFilterDataSourceByName($filters,'STRUCTURE');
            $id = Utilities::getValueInFilterDataSourceByName($filters,'ID');
            $dataSet = array();
            if($structureId){
                $dataSet = $this->calendarWeeklyDaysService->findCalendarWeeklyDaysStructure($structureId,$id);
            }
            $response->addDataset(new DataSet(explode('/',$request->getRoutePath())[1], $dataSet));

        }catch(\Exception $e){
            $response->addMessage(new Response\Message('Erro inesperado :'.$e->getMessage(),Response::STATUS_ERROR));
        }
    }

    public function save(Request\DataSet $request, Response $response)
    {
        try{
            $rows = $request->getDataSet()->getRows()[0];

            list($calendar, $id, $typeSunday, $dailyHoursSunday, $typeMonday, $dailyHoursMonday,
                $typeTuesday, $dailyHoursTuesday, $typeWednesday, $dailyHoursWednesday,
                $typeThursday, $dailyHoursThursday, $typeFriday, $dailyHoursFriday,
                $typeSaturday, $dailyHoursSaturday, $beginDate, $endDate, $name) =
                self::buidingCreateWeekWork($rows);

            $calendarDetail = $this->calendarWeeklyDaysService->saveWeeklyDays($id, $calendar, $name, $typeSunday, $dailyHoursSunday,$typeMonday,
                $dailyHoursMonday, $typeTuesday, $dailyHoursTuesday, $typeWednesday, $dailyHoursWednesday, $typeThursday,
                $dailyHoursThursday, $typeFriday, $dailyHoursFriday, $typeSaturday, $dailyHoursSaturday, $beginDate, $endDate);
            $response->addDataset(new DataSet('calendarWeeklyDays', array("ID" => $calendarDetail->getId())));
            $response->addNotification(new Response\Notification(Messages::SUC_SUCCESSFUL_SAVED));
        }catch(\Exception $e){
            $response->addMessage(new Response\Message('Erro inesperado :'.$e->getMessage(),Response::STATUS_ERROR));
        }
    }

    public function copyWeek(Request\DataSet $request, Response $response){
        set_time_limit(180);
        $row = $request->getDataSet()->getRows()[0];
        $calendarReceiverIds = $row["calendarReceiverId"];
        $selectedWeeks = $row["selectedWeeks"];
        foreach ($calendarReceiverIds as $calendarReceiverId) {
            foreach ($selectedWeeks as $selectedWeek) {
                $rowToBuild = $this->calendarWeeklyDaysService->findCalendarWeeklyDays($selectedWeek['CALENDAR'],$selectedWeek['ID'])[0];
                list($calendar, $id, $typeSunday, $dailyHoursSunday, $typeMonday, $dailyHoursMonday,
                    $typeTuesday, $dailyHoursTuesday, $typeWednesday, $dailyHoursWednesday,
                    $typeThursday, $dailyHoursThursday, $typeFriday, $dailyHoursFriday,
                    $typeSaturday, $dailyHoursSaturday, $beginDate, $endDate, $name) =
                    self::buidingCreateWeekWork($rowToBuild);
                $id=null;
                if($name == self::PADRAO_WORK_WEEK){
                    $calendarReceiverRows = $this->calendarWeeklyDaysService->findCalendarWeeklyDays($calendarReceiverId ,false);
                    foreach($calendarReceiverRows as $calendarReceiverRow){
                        if($calendarReceiverRow["NAME"] == self::PADRAO_WORK_WEEK){
                            $id = $calendarReceiverRow["ID"];
                        }
                    }
                }
                $this->calendarWeeklyDaysService->saveWeeklyDays($id, $calendarReceiverId, $name, $typeSunday, $dailyHoursSunday,$typeMonday,
                    $dailyHoursMonday, $typeTuesday, $dailyHoursTuesday, $typeWednesday, $dailyHoursWednesday, $typeThursday,
                    $dailyHoursThursday, $typeFriday, $dailyHoursFriday, $typeSaturday, $dailyHoursSaturday, $beginDate, $endDate);

            }
        }
    }

    public function delete(Request\DataSet $request, Response $response)
    {
        $dataSet = $request->getDataSet()->getRows();
        foreach ($dataSet as $calendarDetail ){
            $this->calendarDetailService->removeCalendarDetail($calendarDetail['ID']);
        }
        $response->addNotification(new Response\Notification(Messages::SUC_SUCCESSFUL_REMOVED));
    }

    /**
     * @param $rows
     * @return array
     */
    public static function buidingCreateWeekWork($rows)
    {
        $calendar = $rows ['CALENDAR'];
        $id = $rows ['ID'];
        $typeSunday = $rows ['TYPE_SUNDAY'];
        $dailyHoursSunday = $rows ['DAILY_HOURS_SUNDAY'];
        $typeMonday = $rows ['TYPE_MONDAY'];
        $dailyHoursMonday = $rows ['DAILY_HOURS_MONDAY'];
        $typeTuesday = $rows ['TYPE_TUESDAY'];
        $dailyHoursTuesday = $rows ['DAILY_HOURS_TUESDAY'];
        $typeWednesday = $rows ['TYPE_WEDNESDAY'];
        $dailyHoursWednesday = $rows ['DAILY_HOURS_WEDNESDAY'];
        $typeThursday = $rows ['TYPE_THURSDAY'];
        $dailyHoursThursday = $rows ['DAILY_HOURS_THURSDAY'];
        $typeFriday = $rows ['TYPE_FRIDAY'];
        $dailyHoursFriday = $rows ['DAILY_HOURS_FRIDAY'];
        $typeSaturday = $rows ['TYPE_SATURDAY'];
        $dailyHoursSaturday = $rows ['DAILY_HOURS_SATURDAY'];
        $beginDate = $rows ['BEGIN_DATE'];
        $endDate = $rows ['END_DATE'];
        $name = $rows ['NAME'];

        $beginDate = \DateTime::createFromFormat(Utilities::FORMAT_DATE_DEFAULT,$beginDate.' 00:00:00')?:null;
        $endDate = \DateTime::createFromFormat(Utilities::FORMAT_DATE_DEFAULT,$endDate.' 00:00:00')?:null;
        
        $projectId = (empty($rows["PROJECT_ID"])) ? null : $rows["PROJECT_ID"];
        $isApplyChildrenProject = (empty($rows["IS_APPLY_CHILDREN_PROJECT"])) ? null : $rows["IS_APPLY_CHILDREN_PROJECT"];

        return array($calendar, $id, $typeSunday, $dailyHoursSunday, $typeMonday,
            $dailyHoursMonday, $typeTuesday, $dailyHoursTuesday, $typeWednesday,
            $dailyHoursWednesday, $typeThursday, $dailyHoursThursday, $typeFriday,
            $dailyHoursFriday, $typeSaturday, $dailyHoursSaturday, $beginDate, $endDate, $name,
            $projectId, $isApplyChildrenProject);
    }
}