CREATE OR REPLACE PROCEDURE CALC_CRED_PRESUMIDO(
   P_NRSEQUMAPAPU    IN MAPAAPURAC.NRSEQUMAPAPU%TYPE,
   P_CDEMPRESA       IN MAPAAPURAC.CDEMPRESA%TYPE,
   P_CDIMPOSTO       IN MAPAAPURAC.CDIMPOSTO%TYPE,
   P_INSCRICAO       IN MAPAAPURAC.CDINSCESTA%TYPE,
   P_CDAJUSTEITMAPA  IN ITMAPARECUP.CDAJUSTEITMAPA%TYPE,
   P_CDITPROCEDENCIA IN ITMAPARECUP.CDITPROCEDENCIA%TYPE,
   P_CDAJUSTEITSEF   IN ITMAPARECUP.CDAJUSTEITSEF%TYPE)
AS
   V_CDAJUSTEITMAPA    VARCHAR2(10);
   V_CDITPROCEDENCIA   VARCHAR2(10);
   V_CDAJUSTEITSEF     VARCHAR2(03);
   CURSOR C_CODAJUSTECREDP (P_NRSEQUMAPAPU   IN MAPAAPURAC.NRSEQUMAPAPU%TYPE) IS
      (SELECT CDCLASFISC, CDCFOPPADRAO, CDAJUSTEITMAPA, CDAJUSTEITSEF, CDITPROCEDENCIA
         FROM ITMAPARECUP
        WHERE IDCREDPRESUMIDO = 'S'
          AND NRSEQUMAPAPU    = P_NRSEQUMAPAPU
          AND IDTIPOITMAPR    = 'OC');
   TYPE CODAJUSTECREDP IS TABLE OF C_CODAJUSTECREDP%ROWTYPE;
   V_CODAJUSTECREDP    CODAJUSTECREDP;
   V_VRALIQTOTALSAIDA  NUMBER;
   V_DSOUTCREDTOTSAI   VARCHAR2(500);
   V_CDTIPOPERCREDP    VARCHAR2(500);
   V_VRALIQIMPOSREC    NUMBER;
   V_DSOUTCREDIMPREC   VARCHAR2(500);
   V_VRTOTALSAIDA      NUMBER;
   V_VRNORMDEBI        NUMBER;
   V_VRCREDPRES        NUMBER;
   V_STDESCRICAO       VARCHAR2(500);
   V_NRSEQITMAPR       NUMBER;
   V_VRTOTAIMPOS       NUMBER;
   V_VRDEBINORMAL      NUMBER;
   V_VRTOTSAIDA        NUMBER;
BEGIN
   /*Obs.: As alteraes na base de clculo e dbito normal no mapa de apurao foram retiradas
     devido a legislao que os tipos de operao que no pertencem ao crdito
     presumido devem ser considerados normalmente na apurao, com o valor total*/
   V_VRCREDPRES := 0;

   /******** Busca a parametrizao para a gerao do crdito presumido da inscrio estadual do mapa ********/
   BEGIN
      SELECT VRALIQTOTALSAIDA, DSOUTCREDTOTSAI, CDTIPOPERCREDP,
             VRALIQIMPOSREC,   DSOUTCREDIMPREC
        INTO V_VRALIQTOTALSAIDA, V_DSOUTCREDTOTSAI, V_CDTIPOPERCREDP,
             V_VRALIQIMPOSREC,   V_DSOUTCREDIMPREC
        FROM INSCRESTAD
       WHERE CDEMPRESA    = P_CDEMPRESA
         AND CDINSCESTA   = P_INSCRICAO
         AND IDAPURLUCPRE = 'S';
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         V_VRALIQTOTALSAIDA := 0;
         V_DSOUTCREDTOTSAI  := NULL;
         V_CDTIPOPERCREDP   := NULL;
         V_VRALIQIMPOSREC   := 0;
         V_DSOUTCREDIMPREC  := NULL;
   END;

   /******** Busca os items de crdito presumido que j estavam na ITMAPARECUP, de acordo com a parametrizao,
             para salvar os dados digitados pelo usurio, em caso de reapurao de mapas ********/
   OPEN  C_CODAJUSTECREDP (P_NRSEQUMAPAPU);
   FETCH C_CODAJUSTECREDP BULK COLLECT INTO V_CODAJUSTECREDP;
   CLOSE C_CODAJUSTECREDP;

   /******** Crdito Presumido sobre o Valor Total das Sadas ********/
   IF V_VRALIQTOTALSAIDA > 0 THEN
      BEGIN
         SELECT SUM(VRTOTALSAIDA), SUM(VRNORMDEBI)
           INTO V_VRTOTALSAIDA, V_VRNORMDEBI
           FROM (SELECT NVL(SUM(NVL(ROUND(DECODE(IT.CDFISCALIT,'1',IT.VRBASECALCIT,0),2),0.0) +
                        NVL(VALOR_IMPOSTO_ITEM_NFE(IT.CDFILIAL, IT.NRLANCTONF, IT.NRSEQITPROD, '00', 'C','','2'),0.0)),0.0) AS VRTOTALSAIDA,
                        NVL(SUM(ROUND(DECODE(IT.CDFISCALIT,'1',IT.VRIMPOSTOIT + NVL(IT.VRADICFECP,0),0),2)),0.0) AS VRNORMDEBI
                   FROM ITEMPROIMPOS IT, IMPOSTO IM, ITEMPRODUTO IP, PRODUTO PR,
                        (SELECT DISTINCT I.CDFILIAL, I.NRLANCTONF, N.CDEMPRESA, N.CDINSCESTA
                           FROM IMPOSTONF I, NOTAFISCAL N
                          WHERE I.NRSEQUMAPAPU = P_NRSEQUMAPAPU
                            AND I.CDFILIAL     = N.CDFILIAL
                            AND I.NRLANCTONF   = N.NRLANCTONF
                            AND I.CDFISCALNF   = '1'
                            AND I.IDIMPOSTONF  <> '3'
                            AND N.IDENTRSAIDOP = 'S'
                            AND ((INSTR(V_CDTIPOPERCREDP, '_' ||N.IDENTRSAIDOP||N.CDTIPOOPER||'_' ) > 0) OR (V_CDTIPOPERCREDP IS NULL))
                            AND N.IDSISTEMA    <> 'FIS') II
                  WHERE II.CDFILIAL     = IT.CDFILIAL
                    AND II.NRLANCTONF   = IT.NRLANCTONF
                    AND IT.CDIMPOSTO    = IM.CDIMPOSTO
                    AND IM.CDIMPOSTONFE = '00'
                    AND IT.CDFISCALIT   = '1'
                    AND IT.NRITPROIMPOS <> '3'
                    AND IT.CDFILIAL     = IP.CDFILIAL
                    AND IT.NRLANCTONF   = IP.NRLANCTONF
                    AND IT.NRSEQITPROD  = IP.NRSEQITPROD
                    AND IP.CDPRODUTO    = PR.CDPRODUTO
                    AND IT.CDFISCOPERIT NOT IN (SELECT CDCFOPPADRAO
                                                  FROM CREDPRESCFOP
                                                 WHERE CDEMPRESA  = II.CDEMPRESA
                                                   AND CDINSCESTA = II.CDINSCESTA)
                    AND PR.CDCLASFISC   NOT IN (SELECT CDCLASFISC
                                                  FROM CREDPRESNCM
                                                 WHERE CDEMPRESA  = II.CDEMPRESA
                                                   AND CDINSCESTA = II.CDINSCESTA)
                  UNION ALL
                 SELECT NVL(SUM(NVL(ROUND(IP.VRCONTABIL,2),0.0)),0.0) AS VRTOTALSAIDA,
                        NVL(SUM(ROUND(IP.VRIMPOSTO,2)),0.0) AS VRNORMDEBI
                   FROM IMPPRODVENDAFIS IP, PRODUTO PR,
                        (SELECT DISTINCT I.CDFILIAL, N.DTEMISSAO, N.DTENTRSAID,
                                I.NRLANCTONF, N.CDFILIEMIT, N.CDEMPRESA, N.CDINSCESTA
                           FROM IMPOSTONF I, NOTAFISCAL N
                          WHERE I.NRSEQUMAPAPU = P_NRSEQUMAPAPU
                            AND I.CDFILIAL     = N.CDFILIAL
                            AND I.NRLANCTONF   = N.NRLANCTONF
                            AND I.CDFISCALNF   = '1'
                            AND I.IDIMPOSTONF  <> '3'
                            AND N.IDENTRSAIDOP = 'S'
                            AND ((INSTR(V_CDTIPOPERCREDP, '_' ||N.IDENTRSAIDOP||N.CDTIPOOPER||'_' ) > 0) OR (V_CDTIPOPERCREDP IS NULL))
                            AND N.IDSISTEMA    = 'FIS') II
                  WHERE IP.CDFILIAL      = II.CDFILIEMIT
                    AND IP.CDFILIALNFFIS = II.CDFILIAL
                    AND IP.NRLANCTONFFIS = II.NRLANCTONF
                    AND IP.DTEMISSAONFCE = II.DTEMISSAO
                    AND IP.DTENTRVENDA   = II.DTENTRSAID
                    AND ((IP.CDFISCALIT  = '1') OR (IP.CDFISCALIT = '2' AND IP.NRITPROIMPOS = '2'))
                    AND IP.CDIMPOSTO     = '00'
                    AND IP.CDPRODUTO     = PR.CDPRODUTO
                    AND IP.CDFISCOPERIT  NOT IN (SELECT CDCFOPPADRAO
                                                   FROM CREDPRESCFOP
                                                  WHERE CDEMPRESA  = II.CDEMPRESA
                                                    AND CDINSCESTA = II.CDINSCESTA)
                    AND PR.CDCLASFISC    NOT IN (SELECT CDCLASFISC
                                                   FROM CREDPRESNCM
                                                  WHERE CDEMPRESA  = II.CDEMPRESA
                                                    AND CDINSCESTA = II.CDINSCESTA));
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_VRTOTALSAIDA := 0;
            V_VRNORMDEBI   := 0;
      END;

      V_VRCREDPRES  := NVL(V_VRTOTALSAIDA,0) * 0.01 * NVL(V_VRALIQTOTALSAIDA,0);
      V_VRCREDPRES  := ROUND(NVL(V_VRNORMDEBI,0) - NVL(V_VRCREDPRES,0),2);
      V_STDESCRICAO := V_DSOUTCREDTOTSAI;

      /******** Deleta o item de outros crditos gerado pela rotina de crdito presumido, evitando erro na reapurao de mapas ********/
      DELETE FROM ITMAPARECUP
       WHERE NRSEQUMAPAPU    = P_NRSEQUMAPAPU
         AND IDTIPOITMAPR    = 'OC'
         AND IDCREDPRESUMIDO = 'S';

      /******** Recupera os cdigos de ajuste inseridos pelo usurio para o registro de outros crditos gerado
                pela rotina de crdito presumido, parametrizado pela alquota geral (Re-Apurao de Mapas) ********/
      FOR I IN 1 .. V_CODAJUSTECREDP.COUNT LOOP
         IF (V_CODAJUSTECREDP(I).CDCFOPPADRAO IS NULL) AND (V_CODAJUSTECREDP(I).CDCLASFISC IS NULL) THEN
            V_CDAJUSTEITMAPA  := V_CODAJUSTECREDP(I).CDAJUSTEITMAPA;
            V_CDITPROCEDENCIA := V_CODAJUSTECREDP(I).CDITPROCEDENCIA;
            V_CDAJUSTEITSEF   := V_CODAJUSTECREDP(I).CDAJUSTEITSEF;
            EXIT;
         END IF;
      END LOOP;

   /******** Crdito Presumido sobre o Imposto a Recolher ********/
   ELSIF V_VRALIQIMPOSREC > 0 THEN
      V_VRTOTAIMPOS := 0;
      BEGIN
         SELECT VRTOTAIMPOS
           INTO V_VRTOTAIMPOS
           FROM MAPAAPURAC
          WHERE NRSEQUMAPAPU = P_NRSEQUMAPAPU;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_VRTOTAIMPOS := 0;
      END;

      V_VRCREDPRES  := ROUND(NVL(V_VRTOTAIMPOS,0) * 0.01 * NVL(V_VRALIQIMPOSREC,0),2);
      V_STDESCRICAO := NVL(V_DSOUTCREDIMPREC,0);

      /******** Recupera os cdigos de ajuste inseridos pelo usurio para o registro de outros crditos gerado
                pela rotina de crdito presumido, parametrizado sobre o valor total do imposto (Re-Apurao de Mapas) ********/
      V_CDAJUSTEITMAPA  := P_CDAJUSTEITMAPA;
      V_CDITPROCEDENCIA := P_CDITPROCEDENCIA;
      V_CDAJUSTEITSEF   := P_CDAJUSTEITSEF;

   END IF;

   /******** Verifica se deve ser gerado o item de outros crditos, refente ao Crdito Presumido ********/
   IF V_VRCREDPRES > 0 THEN

      /******** Busca o maior sequencial de Outros Crditos ********/
      BEGIN
         SELECT NVL(MAX(NRSEQITMAPR),0) AS NRSEQITMAPR
           INTO V_NRSEQITMAPR
           FROM ITMAPARECUP
          WHERE NRSEQUMAPAPU = P_NRSEQUMAPAPU
            AND IDTIPOITMAPR = 'OC';
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_NRSEQITMAPR := NULL;
      END;

      V_NRSEQITMAPR := NVL(V_NRSEQITMAPR,0)+1;

      /******** Insere o item de outros crditos com o valor do Crdito Presumido calculado ********/
      INSERT INTO ITMAPARECUP
         (NRSEQUMAPAPU, IDTIPOITMAPR, NRSEQITMAPR, DSITEMMAPR, VRITEMMAPR, CDITEMOCOR, DSITEMOCOR,
          DSFLEGALOCOR, NRLANCTONF, CDFILIAL, CDAJUSTEITMAPA, CDAJUSTEITSEF, CDITPROCEDENCIA,
          IDCREDPRESUMIDO, IDDIFALMANUAL, IDCARGATRIBUTARIA)
      VALUES
         (P_NRSEQUMAPAPU, 'OC', LPAD(V_NRSEQITMAPR,10,'0'), V_STDESCRICAO, V_VRCREDPRES, '', '',
          '', '', '', V_CDAJUSTEITMAPA, V_CDAJUSTEITSEF, V_CDITPROCEDENCIA,
          'S', 'S', 'N');
   END IF;

   IF V_VRALIQTOTALSAIDA > 0 THEN
      /******** Crdito Presumido sobre o Valor Total das Sadas Por CFOP ********/
      FOR C_CPCFOP IN (SELECT CDCFOPPADRAO, DSOUTROSCRED, VRALIQUOTA
                         FROM CREDPRESCFOP
                        WHERE CDEMPRESA  = P_CDEMPRESA
                          AND CDINSCESTA = P_INSCRICAO
                        ORDER BY CDCFOPPADRAO) LOOP

         BEGIN
            SELECT SUM(VRTOTALSAIDA), SUM(VRNORMDEBI)
              INTO V_VRTOTALSAIDA, V_VRNORMDEBI
              FROM (SELECT NVL(SUM(NVL(ROUND(DECODE(IT.CDFISCALIT,'1',IT.VRBASECALCIT,0),2),0.0) +
                           NVL(VALOR_IMPOSTO_ITEM_NFE(IT.CDFILIAL, IT.NRLANCTONF, IT.NRSEQITPROD, '00', 'C','','2'),0.0)),0.0) AS VRTOTALSAIDA,
                           NVL(SUM(ROUND(DECODE(IT.CDFISCALIT,'1',IT.VRIMPOSTOIT + NVL(IT.VRADICFECP,0),0),2)),0.0) AS VRNORMDEBI
                      FROM ITEMPROIMPOS IT, IMPOSTO IM, ITEMPRODUTO IP, PRODUTO PR,
                           (SELECT DISTINCT I.CDFILIAL, I.NRLANCTONF, N.CDEMPRESA, N.CDINSCESTA
                              FROM IMPOSTONF I, NOTAFISCAL N
                             WHERE I.NRSEQUMAPAPU = P_NRSEQUMAPAPU
                               AND I.CDFILIAL     = N.CDFILIAL
                               AND I.NRLANCTONF   = N.NRLANCTONF
                               AND I.CDFISCALNF   = '1'
                               AND I.IDIMPOSTONF  <> '3'
                               AND N.IDENTRSAIDOP = 'S'
                               AND ((INSTR(V_CDTIPOPERCREDP, '_' ||N.IDENTRSAIDOP||N.CDTIPOOPER||'_' ) > 0) OR (V_CDTIPOPERCREDP IS NULL))
                               AND N.IDSISTEMA    <> 'FIS') II
                     WHERE II.CDFILIAL     = IT.CDFILIAL
                       AND II.NRLANCTONF   = IT.NRLANCTONF
                       AND IT.CDIMPOSTO    = IM.CDIMPOSTO
                       AND IM.CDIMPOSTONFE = '00'
                       AND IT.CDFISCALIT   = '1'
                       AND IT.NRITPROIMPOS <> '3'
                       AND IT.CDFISCOPERIT = C_CPCFOP.CDCFOPPADRAO
                       AND IT.CDFILIAL     = IP.CDFILIAL
                       AND IT.NRLANCTONF   = IP.NRLANCTONF
                       AND IT.NRSEQITPROD  = IP.NRSEQITPROD
                       AND IP.CDPRODUTO    = PR.CDPRODUTO
                       AND PR.CDCLASFISC NOT IN (SELECT CDCLASFISC
                                                   FROM CREDPRESNCM
                                                  WHERE CDEMPRESA  = II.CDEMPRESA
                                                    AND CDINSCESTA = II.CDINSCESTA)
                     UNION ALL
                    SELECT NVL(SUM(NVL(ROUND(IP.VRCONTABIL,2),0.0)),0.0) AS VRTOTALSAIDA,
                           NVL(SUM(ROUND(IP.VRIMPOSTO,2)),0.0) AS VRNORMDEBI
                      FROM IMPPRODVENDAFIS IP, PRODUTO PR,
                           (SELECT DISTINCT I.CDFILIAL, N.DTEMISSAO, N.DTENTRSAID,
                                   I.NRLANCTONF, N.CDFILIEMIT, N.CDEMPRESA, N.CDINSCESTA
                              FROM IMPOSTONF I, NOTAFISCAL N
                             WHERE I.NRSEQUMAPAPU = P_NRSEQUMAPAPU
                               AND I.CDFILIAL     = N.CDFILIAL
                               AND I.NRLANCTONF   = N.NRLANCTONF
                               AND I.CDFISCALNF   = '1'
                               AND I.IDIMPOSTONF  <> '3'
                               AND N.IDENTRSAIDOP = 'S'
                               AND ((INSTR(V_CDTIPOPERCREDP, '_' ||N.IDENTRSAIDOP||N.CDTIPOOPER||'_' ) > 0) OR (V_CDTIPOPERCREDP IS NULL))
                               AND N.IDSISTEMA    = 'FIS') II
                     WHERE IP.CDFILIAL      = II.CDFILIEMIT
                       AND IP.CDFILIALNFFIS = II.CDFILIAL
                       AND IP.NRLANCTONFFIS = II.NRLANCTONF
                       AND IP.DTEMISSAONFCE = II.DTEMISSAO
                       AND IP.DTENTRVENDA   = II.DTENTRSAID
                       AND ((IP.CDFISCALIT = '1') OR (IP.CDFISCALIT = '2' AND IP.NRITPROIMPOS = '2'))
                       AND IP.CDIMPOSTO    = '00'
                       AND IP.CDPRODUTO    = PR.CDPRODUTO
                       AND IP.CDFISCOPERIT = C_CPCFOP.CDCFOPPADRAO
                       AND PR.CDCLASFISC   NOT IN (SELECT CDCLASFISC
                                                     FROM CREDPRESNCM
                                                    WHERE CDEMPRESA  = II.CDEMPRESA
                                                      AND CDINSCESTA = II.CDINSCESTA));
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_VRTOTALSAIDA := 0;
               V_VRNORMDEBI   := 0;
         END;

         V_VRCREDPRES  := NVL(V_VRTOTALSAIDA,0) * 0.01 * NVL(C_CPCFOP.VRALIQUOTA,0);
         V_VRCREDPRES  := ROUND(NVL(V_VRNORMDEBI,0) - NVL(V_VRCREDPRES,0),2);
         V_STDESCRICAO := C_CPCFOP.DSOUTROSCRED;

         /******** Verifica se deve ser gerado o item de outros crditos, refente ao Crdito Presumido ********/
         IF V_VRCREDPRES > 0 THEN

            /******** Busca o maior sequencial de Outros Crditos ********/
            BEGIN
               SELECT NVL(MAX(NRSEQITMAPR),0) AS NRSEQITMAPR
                 INTO V_NRSEQITMAPR
                 FROM ITMAPARECUP
                WHERE NRSEQUMAPAPU = P_NRSEQUMAPAPU
                  AND IDTIPOITMAPR = 'OC';
            EXCEPTION
               WHEN NO_DATA_FOUND THEN
                  V_NRSEQITMAPR := NULL;
            END;

            V_NRSEQITMAPR := NVL(V_NRSEQITMAPR,0)+1;

            /******** Recupera os cdigos de ajuste inseridos pelo usurio para o registro de outros crditos gerado
                pela rotina de crdito presumido, parametrizado pela alquota por CFOP (Re-Apurao de Mapas) ********/
            FOR I IN 1 .. V_CODAJUSTECREDP.COUNT LOOP
               IF V_CODAJUSTECREDP(I).CDCFOPPADRAO = C_CPCFOP.CDCFOPPADRAO THEN
                  V_CDAJUSTEITMAPA  := V_CODAJUSTECREDP(I).CDAJUSTEITMAPA;
                  V_CDITPROCEDENCIA := V_CODAJUSTECREDP(I).CDITPROCEDENCIA;
                  V_CDAJUSTEITSEF   := V_CODAJUSTECREDP(I).CDAJUSTEITSEF;
                  EXIT;
               END IF;
            END LOOP;

            /******** Insere o item de outros crditos com o valor do Crdito Presumido calculado ********/
            INSERT INTO ITMAPARECUP
               (NRSEQUMAPAPU, IDTIPOITMAPR, NRSEQITMAPR, DSITEMMAPR, VRITEMMAPR, CDITEMOCOR, DSITEMOCOR,
                DSFLEGALOCOR, NRLANCTONF, CDFILIAL, CDAJUSTEITMAPA, CDAJUSTEITSEF, CDITPROCEDENCIA,
                IDCREDPRESUMIDO, IDDIFALMANUAL, IDCARGATRIBUTARIA, CDCFOPPADRAO)
            VALUES
               (P_NRSEQUMAPAPU, 'OC', LPAD(V_NRSEQITMAPR,10,'0'), V_STDESCRICAO, V_VRCREDPRES, '', '',
                '', '', '', V_CDAJUSTEITMAPA, V_CDAJUSTEITSEF, V_CDITPROCEDENCIA,
                'S', 'S', 'N', C_CPCFOP.CDCFOPPADRAO);
         END IF;
      END LOOP;
      /******** Crdito Presumido sobre o Valor Total das Sadas Por NCM ********/
      FOR C_CPNCM IN (SELECT CDCLASFISC, DSOUTROSCRED, VRALIQUOTA
                        FROM CREDPRESNCM
                       WHERE CDEMPRESA  = P_CDEMPRESA
                         AND CDINSCESTA = P_INSCRICAO
                       ORDER BY CDCLASFISC) LOOP

         BEGIN
            SELECT SUM(VRTOTALSAIDA), SUM(VRNORMDEBI)
              INTO V_VRTOTALSAIDA, V_VRNORMDEBI
              FROM (SELECT NVL(SUM(NVL(ROUND(DECODE(IT.CDFISCALIT,'1',IT.VRBASECALCIT,0),2),0.0) +
                           NVL(VALOR_IMPOSTO_ITEM_NFE(IT.CDFILIAL, IT.NRLANCTONF, IT.NRSEQITPROD, '00', 'C','','2'),0.0)),0.0) AS VRTOTALSAIDA,
                           NVL(SUM(ROUND(DECODE(IT.CDFISCALIT,'1',IT.VRIMPOSTOIT + NVL(IT.VRADICFECP,0),0),2)),0.0) AS VRNORMDEBI
                      FROM ITEMPROIMPOS IT, IMPOSTO IM, ITEMPRODUTO IP, PRODUTO PR,
                           (SELECT DISTINCT I.CDFILIAL, I.NRLANCTONF, N.CDEMPRESA, N.CDINSCESTA
                              FROM IMPOSTONF I, NOTAFISCAL N
                             WHERE I.NRSEQUMAPAPU = P_NRSEQUMAPAPU
                               AND I.CDFILIAL     = N.CDFILIAL
                               AND I.NRLANCTONF   = N.NRLANCTONF
                               AND I.CDFISCALNF   = '1'
                               AND I.IDIMPOSTONF  <> '3'
                               AND N.IDENTRSAIDOP = 'S'
                               AND ((INSTR(V_CDTIPOPERCREDP, '_' ||N.IDENTRSAIDOP||N.CDTIPOOPER||'_' ) > 0) OR (V_CDTIPOPERCREDP IS NULL))
                               AND N.IDSISTEMA    <> 'FIS') II
                     WHERE II.CDFILIAL     = IT.CDFILIAL
                       AND II.NRLANCTONF   = IT.NRLANCTONF
                       AND IT.CDIMPOSTO    = IM.CDIMPOSTO
                       AND IM.CDIMPOSTONFE = '00'
                       AND IT.CDFISCALIT   = '1'
                       AND IT.NRITPROIMPOS <> '3'
                       AND IT.CDFILIAL     = IP.CDFILIAL
                       AND IT.NRLANCTONF   = IP.NRLANCTONF
                       AND IT.NRSEQITPROD  = IP.NRSEQITPROD
                       AND IP.CDPRODUTO    = PR.CDPRODUTO
                       AND PR.CDCLASFISC   = C_CPNCM.CDCLASFISC
                     UNION ALL
                    SELECT NVL(SUM(NVL(ROUND(IP.VRCONTABIL,2),0.0)),0.0) AS VRTOTALSAIDA,
                           NVL(SUM(ROUND(IP.VRIMPOSTO,2)),0.0) AS VRNORMDEBI
                      FROM IMPPRODVENDAFIS IP, PRODUTO PR,
                           (SELECT DISTINCT I.CDFILIAL, N.DTEMISSAO, N.DTENTRSAID,
                                   I.NRLANCTONF, N.CDFILIEMIT, N.CDEMPRESA, N.CDINSCESTA
                              FROM IMPOSTONF I, NOTAFISCAL N
                             WHERE I.NRSEQUMAPAPU = P_NRSEQUMAPAPU
                               AND I.CDFILIAL     = N.CDFILIAL
                               AND I.NRLANCTONF   = N.NRLANCTONF
                               AND I.CDFISCALNF   = '1'
                               AND I.IDIMPOSTONF  <> '3'
                               AND N.IDENTRSAIDOP = 'S'
                               AND ((INSTR(V_CDTIPOPERCREDP, '_' ||N.IDENTRSAIDOP||N.CDTIPOOPER||'_' ) > 0) OR (V_CDTIPOPERCREDP IS NULL))
                               AND N.IDSISTEMA    = 'FIS') II
                     WHERE IP.CDFILIAL      = II.CDFILIEMIT
                       AND IP.CDFILIALNFFIS = II.CDFILIAL
                       AND IP.NRLANCTONFFIS = II.NRLANCTONF
                       AND IP.DTEMISSAONFCE = II.DTEMISSAO
                       AND IP.DTENTRVENDA   = II.DTENTRSAID
                       AND ((IP.CDFISCALIT = '1') OR (IP.CDFISCALIT = '2' AND IP.NRITPROIMPOS = '2'))
                       AND IP.CDIMPOSTO    = '00'
                       AND IP.CDPRODUTO    = PR.CDPRODUTO
                       AND PR.CDCLASFISC   = C_CPNCM.CDCLASFISC);
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_VRTOTALSAIDA := 0;
               V_VRNORMDEBI   := 0;
         END;

         V_VRCREDPRES  := NVL(V_VRTOTALSAIDA,0) * 0.01 * NVL(C_CPNCM.VRALIQUOTA,0);
         V_VRCREDPRES  := ROUND(NVL(V_VRNORMDEBI,0) - NVL(V_VRCREDPRES,0),2);
         V_STDESCRICAO := C_CPNCM.DSOUTROSCRED;

         /******** Verifica se deve ser gerado o item de outros crditos, refente ao Crdito Presumido ********/
         IF V_VRCREDPRES > 0 THEN

            /******** Busca o maior sequencial de Outros Crditos ********/
            BEGIN
               SELECT NVL(MAX(NRSEQITMAPR),0) AS NRSEQITMAPR
                 INTO V_NRSEQITMAPR
                 FROM ITMAPARECUP
                WHERE NRSEQUMAPAPU = P_NRSEQUMAPAPU
                  AND IDTIPOITMAPR = 'OC';
            EXCEPTION
               WHEN NO_DATA_FOUND THEN
                  V_NRSEQITMAPR := NULL;
            END;

            V_NRSEQITMAPR := NVL(V_NRSEQITMAPR,0)+1;

            /******** Recupera os cdigos de ajuste inseridos pelo usurio para o registro de outros crditos gerado
                pela rotina de crdito presumido, parametrizado pela alquota por CFOP (Re-Apurao de Mapas) ********/
            FOR I IN 1 .. V_CODAJUSTECREDP.COUNT LOOP
               IF V_CODAJUSTECREDP(I).CDCLASFISC = C_CPNCM.CDCLASFISC THEN
                  V_CDAJUSTEITMAPA  := V_CODAJUSTECREDP(I).CDAJUSTEITMAPA;
                  V_CDITPROCEDENCIA := V_CODAJUSTECREDP(I).CDITPROCEDENCIA;
                  V_CDAJUSTEITSEF   := V_CODAJUSTECREDP(I).CDAJUSTEITSEF;
                  EXIT;
               END IF;
            END LOOP;

            /******** Insere o item de outros crditos com o valor do Crdito Presumido calculado ********/
            INSERT INTO ITMAPARECUP
               (NRSEQUMAPAPU, IDTIPOITMAPR, NRSEQITMAPR, DSITEMMAPR, VRITEMMAPR, CDITEMOCOR, DSITEMOCOR,
                DSFLEGALOCOR, NRLANCTONF, CDFILIAL, CDAJUSTEITMAPA, CDAJUSTEITSEF, CDITPROCEDENCIA,
                IDCREDPRESUMIDO, IDDIFALMANUAL, IDCARGATRIBUTARIA, CDCLASFISC)
            VALUES
               (P_NRSEQUMAPAPU, 'OC', LPAD(V_NRSEQITMAPR,10,'0'), V_STDESCRICAO, V_VRCREDPRES, '', '',
                '', '', '', V_CDAJUSTEITMAPA, V_CDAJUSTEITSEF, V_CDITPROCEDENCIA,
                'S', 'S', 'N', C_CPNCM.CDCLASFISC);
         END IF;
      END LOOP;
   END IF;
END;